@@ -79,6 +79,15 @@ sub field {
     my $this = shift();
     my($name, $lname) = @_;
 
+    if (!defined $lname && exists $this->{layers}->{'master-override'}) {
+	# Special case: master records have only one layer
+	$lname = 'master-override';
+	my $x = $this->{layers}->{'master-override'}->{fields};
+	warn "using master-override layer for field '$name': {" .
+	    join(", ", map { "$_='" . $x->{$_} . "'" } sort keys %$x) .
+	    "}";
+    }
+
     if (!defined $lname && $name eq "id") {
 	# Special case: if asking for "id" in a world record (one that
 	# has no override layer), be sure to return the ID from the
@@ -113,7 +122,8 @@ sub setField {
     die "setField() called on non-Master record"
 	if !exists $this->{layers}->{'master-override'};
 
-
+    ### We should use the Layer API instead of poking inside hashes.
+    $this->{layers}->{'master-override'}->{fields}->{$name} = $value;
 }
 
 sub _show {
