@@ -101,8 +101,8 @@ sub records {
 
 sub world {
     my $this = shift();
-    my($realm, $query, $facets, $start, $count) = @_;
-    return $this->_list("world", $realm, $query, undef, undef, $facets, $start, $count);
+    my($realm, $query, $facets, $start, $count, $recursive) = @_;
+    return $this->_list("world", $realm, $query, undef, undef, $facets, $start, $count, $recursive);
 }
 
 sub merged {
@@ -114,7 +114,7 @@ sub merged {
 # Internal entry point, includes logging
 sub _list {
     my $this = shift();
-    my($listType, $realm, $query, $user, $noConstraint, $facets, $start, $count) = @_;
+    my($listType, $realm, $query, $user, $noConstraint, $facets, $start, $count, $recursive) = @_;
 
     if (ref $query eq "HASH") {
 	$query = _hash2cql(%$query);
@@ -122,18 +122,19 @@ sub _list {
 
     $this->_logTorusOp($listType, realm=>$realm, query=>$query,
 		       user=>$user, noConstraint=>$noConstraint,
-		       facets=>$facets, start=>$start, count=>$count);
+		       facets=>$facets, start=>$start, count=>$count,
+		       recursive=>$recursive);
     # Can't just use @_ here, as $query may have been rewritten
-    return $this->_list_nolog($listType, $realm, $query, $user, $noConstraint, $facets, $start, $count);
+    return $this->_list_nolog($listType, $realm, $query, $user, $noConstraint, $facets, $start, $count, $recursive);
 }
 
 
 # Internal entry point without logging
 sub _list_nolog {
     my $this = shift();
-    my($listType, $realm, $query, $user, $noConstraint, $facets, $start, $count) = @_;
+    my($listType, $realm, $query, $user, $noConstraint, $facets, $start, $count, $recursive) = @_;
 
-    my $uri = $this->_listURI($listType, $realm, $query, $user, $noConstraint, $facets, $start, $count);
+    my $uri = $this->_listURI($listType, $realm, $query, $user, $noConstraint, $facets, $start, $count, $recursive);
     my $simple = $this->_getAsXML($uri);
 
     my $ntotal = $simple->{total};
@@ -197,7 +198,7 @@ sub worldURI {
 #
 sub _listURI {
     my $this = shift();
-    my($listType, $realm, $query, $user, $noConstraint, $facets, $start, $count) = @_;
+    my($listType, $realm, $query, $user, $noConstraint, $facets, $start, $count, $recursive) = @_;
     $query = undef if defined $query && $query eq "";
     if (!$noConstraint && !$this->{isAuth} &&
 	$this->admin()->conf("constrainIdentity")) {
@@ -213,6 +214,7 @@ sub _listURI {
     $params{facets} = $facets if defined $facets;
     $params{start} = $start if defined $start;
     $params{count} = $count if defined $count;
+    $params{recursive} = $recursive if defined $recursive;
 
     if (%params) {
 	$uri .= "?" . join("&", map { uri_escape_utf8($_) . "=" .
